"use client";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect } from "react";
import { EditorInterface } from "./EditorInterface";
import { Toolbar } from "./Toolbar";
import { MenuBar } from "./Menubar";
import { useEditorStore } from "../store/useEditorState";
import "../styles.css";
export function Editor({ readOnly = false, initialContent, getTextContent, getJSONContent, getHTMLContent, onSave, onClose, onCreateNew, toolbarRight, editorOpts, getEditorOpts, hideToolbar = false, hideMenubar = false, }) {
    const { editor, editorOpts: editorOptions, setEditorOpts } = useEditorStore();
    useEffect(() => {
        if (editor) {
            editor.setEditable(!readOnly);
        }
    }, [editor, readOnly]);
    useEffect(() => {
        if (editor && getEditorOpts) {
            getEditorOpts(editorOptions);
        }
    }, [editorOptions, getEditorOpts]);
    useEffect(() => {
        if (editor && editorOpts) {
            setEditorOpts(editorOpts);
        }
    }, [editor, editorOpts]);
    useEffect(() => {
        if (editor && initialContent) {
            editor.commands.setContent(initialContent);
        }
    }, [editor, initialContent]);
    useEffect(() => {
        if (getTextContent) {
            getTextContent(editor?.getText() || "");
        }
        if (getJSONContent) {
            getJSONContent(editor?.getJSON() || {});
        }
        if (getHTMLContent) {
            getHTMLContent(editor?.getHTML() || "");
        }
    }, [editor?.getText(), editor?.getJSON(), editor?.getHTML(), getTextContent]);
    return (_jsxs("div", { className: "min-h-screen bg-[#FAFBFD]", children: [(!hideMenubar || !hideToolbar) && (_jsxs("div", { className: "flex flex-col pt-2 gap-y-2 sticky top-0 left-0 right-0 z-10 bg-[#FAFBFD] print:hidden text-slate-700", children: [!hideMenubar && (_jsx(MenuBar, { onSave: onSave, onClose: onClose, onCreateNew: onCreateNew })), !hideToolbar && (_jsx(Toolbar, { onSave: onSave, toolbarRight: toolbarRight }))] })), _jsx("div", { className: "print:pt-0", children: _jsx(EditorInterface, {}) })] }));
}
Editor.defaultProps = {
    initialContent: "",
    readOnly: false,
    toolbarRight: null,
    getHTMLContent: () => { },
    getJSONContent: () => { },
    getTextContent: () => { },
    onClose: () => { },
    onSave: () => { },
    onCreateNew: () => { },
    getEditorOpts: () => {
        return { padding: { top: 0, bottom: 0, left: 0, right: 0 } };
    },
    editorOpts: { padding: { top: 0, bottom: 0, left: 0, right: 0 } },
    hideToolbar: false,
    hideMenubar: false,
};
